@@ -1,4 +1,5 @@
 from typing import Optional
+from tim.endpoint import endpoint as default_endpoint
 
 
 class Credentials:
@@ -13,7 +14,7 @@ class Credentials:
       self,
       email: str,
       password: str,
-      endpoint: str = "https://tim-platform.tangent.works/api/v5",
+      endpoint: str = default_endpoint,
       clientName: str = "Python Client",
   ):
     self.__email = email
