@@ -1,5 +1,6 @@
 from time import sleep
 from pandas.core.frame import DataFrame
+from copy import copy
 from typing import List, Union, Callable, Optional
 from tim.core.credentials import Credentials
 from tim.core.api import execute_request
@@ -24,15 +25,16 @@ def upload_csv(
   if not __is_valid_csv_configuration(configuration):
     raise ValueError("Invalid configuration input.")
 
-  configuration["csvSeparator"
-               ] = CSVSeparator.SEMICOLON.value  # pyright: reportTypedDictNotRequiredAccess=false
+  conf_with_csv_separator: UploadCSVConfiguration = copy(configuration)
+  conf_with_csv_separator["csvSeparator"
+                         ] = CSVSeparator.SEMICOLON.value  # pyright: reportTypedDictNotRequiredAccess=false
 
   return execute_request(
       credentials=credentials,
       method="post",
       path="/datasets/csv",
-      body=configuration,
-      file=dataset.to_csv(sep=configuration["csvSeparator"], index=False),
+      body=conf_with_csv_separator,
+      file=dataset.to_csv(sep=conf_with_csv_separator["csvSeparator"], index=False),
   )
 
 
