@@ -1,5 +1,5 @@
 from typing_extensions import TypedDict
-from tim.types import ObjId, SortDirection
+from tim.types import ObjId
 
 
 class Workspace(TypedDict):
@@ -15,7 +15,7 @@ class Workspace(TypedDict):
 
 
 class WorkspaceListPayload(TypedDict, total=False):
+  userGroupId: str
+  sort: str
   offset: int
   limit: int
-  userGroupId: str
-  sort: SortDirection
