@@ -8,13 +8,11 @@ def get_workspaces(
     credentials: Credentials,
     offset: int,
     limit: int,
-    userGroupId: Union[str, None] = None,
+    user_group_id: Union[str, None] = None,
     sort: Union[str, None] = None
 ) -> List[Workspace]:
   payload = WorkspaceListPayload(offset=offset, limit=limit)
-  if userGroupId: payload['userGroupId'] = userGroupId
+  if user_group_id: payload['userGroupId'] = user_group_id
   if sort: payload['sort'] = sort
 
-  return execute_request(
-      credentials=credentials, method='get', path=f'/workspaces', params=payload
-  )
+  return execute_request(credentials=credentials, method='get', path=f'/workspaces', params=payload)
