@@ -13,6 +13,7 @@ from tim.data_sources.forecast import build_forecasting_model, execute, get_fore
 from tim.data_sources.use_case import create_use_case, UseCaseConfiguration
 from tim.data_sources.workspace import get_workspaces
 from tim.types import ExecuteResponse, Status, Id, StatusResponse
+from tim.endpoint import endpoint
 
 
 class Tim:
@@ -22,7 +23,7 @@ class Tim:
       self,
       email: str,
       password: str,
-      endpoint: str = "https://tim-platform.tangent.works/api/v5",
+      endpoint: str = endpoint,
       clientName: str = "Python Client",
   ):
     self.__credentials = Credentials(email, password, endpoint, clientName)
@@ -48,8 +49,7 @@ class Tim:
 
         Returns
         -------
-        id : str
-        dataset : Dict | None
+        dataset_metadata : Dict | None
         	Dict when successful; None when unsuccessful
         logs : list of Dict
         """
@@ -259,8 +259,8 @@ class Tim:
       DataFrame when successful; None when unsuccessful
     accuracies : Dict | None
       Dict when successful; None when unsuccessful
-    dataset_logs : list of Dict
     forecasting_logs : list of Dict
+    dataset_logs : list of Dict
     """
     if job_configuration and "data" in job_configuration and "dataVersion" in job_configuration["data"]:
       raise ValueError("'dataVersion' is not a valid key in in data in job_configuration for this function.")
@@ -469,8 +469,6 @@ class Tim:
       Dict when successful; None when unsuccessful
     table_result : DataFrame | None
       Dict when successful; None when unsuccessful
-    accuracies : Dict | None
-      Dict when successful; None when unsuccessful
     logs : list of Dict
     """
     metadata = model_result = table_result = None
