@@ -2,6 +2,10 @@ from enum import Enum
 from typing_extensions import TypedDict
 
 
+class Id(TypedDict):
+  id: str
+
+
 class Origin(Enum):
   REGISTRATION = 'Registration'
   EXECUTION = 'Executed'
@@ -49,3 +53,12 @@ class SortDirection(Enum):
   UPDATED_AT_ASC = '+updatedAt'
   TITLE_DESC = '-title'
   TITLE_ASC = '+title'
+
+
+class ExecuteResponse(TypedDict):
+  message: str
+  code: str
+
+
+class Version(TypedDict):
+  version: Id
